# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deepdriver/sdk/interface/grpc_interface.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-deepdriver/sdk/interface/grpc_interface.proto\"\x93\x01\n\x10UploadLogRequest\x12\x16\n\x04item\x18\x01 \x03(\x0b\x32\x08.LogItem\x12\x16\n\x04step\x18\x02 \x01(\x0b\x32\x08.LogStep\x12\x15\n\x03run\x18\x03 \x01(\x0b\x32\x08.RunInfo\x12\x10\n\x08teamName\x18\x04 \x01(\t\x12\x0f\n\x07\x65xpName\x18\x05 \x01(\t\x12\x15\n\rauthorization\x18\x06 \x01(\t\"8\n\x11UploadLogResponse\x12#\n\nrsp_result\x18\x01 \x01(\x0b\x32\x0f.ResponseResult\"1\n\x0eResponseResult\x12\x0e\n\x06result\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\"\x94\x01\n\x07LogItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x17\n\rvalueAsString\x18\x02 \x01(\tH\x00\x12\x14\n\nvalueAsInt\x18\x03 \x01(\x05H\x00\x12\x16\n\x0cvalueAsFloat\x18\x04 \x01(\x02H\x00\x12\x15\n\x0bvalueAsLong\x18\x05 \x01(\x03H\x00\x12\x15\n\x0bvalueAsBool\x18\x06 \x01(\x08H\x00\x42\x07\n\x05value\"\x16\n\x07LogStep\x12\x0b\n\x03num\x18\x01 \x01(\x03\"\x19\n\x07RunInfo\x12\x0e\n\x06run_id\x18\x01 \x01(\x03\"Q\n\x15UploadArtifactRequest\x12!\n\x08\x61rtifact\x18\x01 \x01(\x0b\x32\x0f.ArtifactRecord\x12\x15\n\rauthorization\x18\x02 \x01(\t\"R\n\x16UploadArtifactResponse\x12\x13\n\x0b\x61rtifact_id\x18\x01 \x01(\x03\x12#\n\nrsp_result\x18\x02 \x01(\x0b\x32\x0f.ResponseResult\"\xd2\x01\n\x0e\x41rtifactRecord\x12\x0e\n\x06run_id\x18\x01 \x01(\x03\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0e\n\x06\x64igest\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x12\n\nversioning\x18\x06 \x01(\t\x12\x10\n\x08metadata\x18\x07 \x01(\t\x12\x10\n\x08teamName\x18\x08 \x01(\t\x12\x0f\n\x07\x65xpName\x18\t \x01(\t\x12&\n\x0e\x61rtifact_entry\x18\n \x03(\x0b\x32\x0e.ArtifactEntry\"\x98\x01\n\rArtifactEntry\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0e\n\x06\x64igest\x18\x02 \x01(\t\x12\x0c\n\x04size\x18\x03 \x01(\x03\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\r\n\x05lfsYN\x18\x05 \x01(\t\x12\x0f\n\x07repoTag\x18\x06 \x01(\t\x12\x0b\n\x03key\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\x12\x10\n\x08metadata\x18\t \x01(\t\"\xad\x02\n\x11UploadFileRequest\x12\x12\n\nuploadType\x18\x01 \x01(\t\x12\x19\n\x04\x66ile\x18\x02 \x01(\x0b\x32\x0b.FileRecord\x12\x13\n\x0b\x61rtifact_id\x18\x03 \x01(\x03\x12\x0e\n\x06run_id\x18\x04 \x01(\x03\x12\x14\n\x0c\x61rtifactName\x18\x05 \x01(\t\x12\x14\n\x0c\x61rtifactType\x18\x06 \x01(\t\x12\x0e\n\x06\x64igest\x18\x07 \x01(\t\x12\x14\n\x0clast_file_yn\x18\x08 \x01(\t\x12\x15\n\rauthorization\x18\t \x01(\t\x12\x10\n\x08teamName\x18\n \x01(\t\x12\x0f\n\x07\x65xpName\x18\x0b \x01(\t\x12\x0f\n\x07runName\x18\x0c \x01(\t\x12\'\n\x0ftotal_file_info\x18\r \x01(\x0b\x32\x0e.TotalFileInfo\"9\n\x12UploadFileResponse\x12#\n\nrsp_result\x18\x01 \x01(\x0b\x32\x0f.ResponseResult\"%\n\nFileRecord\x12\x17\n\x04\x66ile\x18\x01 \x01(\x0b\x32\t.FileItem\"H\n\x08\x46ileItem\x12\x1d\n\x08\x66ilepath\x18\x01 \x01(\x0b\x32\t.FilePathH\x00\x12\x12\n\x08\x63ontents\x18\x02 \x01(\x0cH\x00\x42\t\n\x07request\"+\n\x08\x46ilePath\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\troot_path\x18\x02 \x01(\t\">\n\rTotalFileInfo\x12\x0e\n\x06\x64igest\x18\x01 \x01(\t\x12\x1d\n\x05\x65ntry\x18\x02 \x03(\x0b\x32\x0e.ArtifactEntry\"\xa4\x01\n\x12UseArtifactRequest\x12\x15\n\rartifact_name\x18\x01 \x01(\t\x12\x15\n\rartifact_type\x18\x02 \x01(\t\x12\x14\n\x0c\x61rtifact_tag\x18\x03 \x01(\t\x12\x11\n\tteam_name\x18\x04 \x01(\t\x12\x10\n\x08\x65xp_name\x18\x05 \x01(\t\x12\x0e\n\x06run_id\x18\x06 \x01(\x03\x12\x15\n\rauthorization\x18\x07 \x01(\t\"r\n\x13UseArtifactResponse\x12\x13\n\x0b\x61rtifact_id\x18\x01 \x01(\x03\x12#\n\nrsp_result\x18\x02 \x01(\x0b\x32\x0f.ResponseResult\x12!\n\x08\x61rtifact\x18\x03 \x01(\x0b\x32\x0f.ArtifactRecord\"\xd2\x01\n\x13\x44ownloadFileRequest\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x13\n\x0b\x61rtifact_id\x18\x02 \x01(\x03\x12\x14\n\x0c\x61rtifactName\x18\x03 \x01(\t\x12\x14\n\x0c\x61rtifactType\x18\x04 \x01(\t\x12\x10\n\x08teamName\x18\x05 \x01(\t\x12\x0f\n\x07\x65xpName\x18\x06 \x01(\t\x12\x12\n\nversioning\x18\x07 \x01(\t\x12\r\n\x05lfsYN\x18\x08 \x01(\t\x12\x0f\n\x07repoTag\x18\t \x01(\t\x12\x15\n\rauthorization\x18\n \x01(\t\"]\n\x14\x44ownloadFileResponse\x12#\n\nrsp_result\x18\x01 \x01(\x0b\x32\x0f.ResponseResult\x12\x10\n\x08\x63ontents\x18\x02 \x01(\x0c\x12\x0e\n\x06\x64igest\x18\x03 \x01(\t\"\x97\x01\n\nConfigItem\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x17\n\rvalueAsString\x18\x02 \x01(\tH\x00\x12\x14\n\nvalueAsInt\x18\x03 \x01(\x05H\x00\x12\x16\n\x0cvalueAsFloat\x18\x04 \x01(\x02H\x00\x12\x15\n\x0bvalueAsLong\x18\x05 \x01(\x03H\x00\x12\x15\n\x0bvalueAsBool\x18\x06 \x01(\x08H\x00\x42\x07\n\x05value\"y\n\x13UpdateConfigRequest\x12\r\n\x05runId\x18\x01 \x01(\x03\x12\x19\n\x04item\x18\x02 \x03(\x0b\x32\x0b.ConfigItem\x12\x10\n\x08teamName\x18\x03 \x01(\t\x12\x0f\n\x07\x65xpName\x18\x04 \x01(\t\x12\x15\n\rauthorization\x18\x05 \x01(\t\";\n\x14UpdateConfigResponse\x12#\n\nrsp_result\x18\x01 \x01(\x0b\x32\x0f.ResponseResult\"Z\n\x10SendAlertRequest\x12\r\n\x05runId\x18\x01 \x01(\x03\x12\x10\n\x08teamName\x18\x02 \x01(\t\x12\x0f\n\x07\x65xpName\x18\x03 \x01(\t\x12\x14\n\x0c\x61lertMessage\x18\x04 \x01(\t\"8\n\x11SendAlertResponse\x12#\n\nrsp_result\x18\x01 \x01(\x0b\x32\x0f.ResponseResult2\xb9\x03\n\x08Resource\x12\x35\n\nupload_log\x12\x11.UploadLogRequest\x1a\x12.UploadLogResponse\"\x00\x12\x44\n\x0fupload_artifact\x12\x16.UploadArtifactRequest\x1a\x17.UploadArtifactResponse\"\x00\x12:\n\x0bupload_file\x12\x12.UploadFileRequest\x1a\x13.UploadFileResponse\"\x00(\x01\x12;\n\x0cuse_artifact\x12\x13.UseArtifactRequest\x1a\x14.UseArtifactResponse\"\x00\x12@\n\rdownload_file\x12\x14.DownloadFileRequest\x1a\x15.DownloadFileResponse\"\x00\x30\x01\x12>\n\rupdate_config\x12\x14.UpdateConfigRequest\x1a\x15.UpdateConfigResponse\"\x00\x12\x35\n\nsend_alert\x12\x11.SendAlertRequest\x1a\x12.SendAlertResponse\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deepdriver.sdk.interface.grpc_interface_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _UPLOADLOGREQUEST._serialized_start=50
  _UPLOADLOGREQUEST._serialized_end=197
  _UPLOADLOGRESPONSE._serialized_start=199
  _UPLOADLOGRESPONSE._serialized_end=255
  _RESPONSERESULT._serialized_start=257
  _RESPONSERESULT._serialized_end=306
  _LOGITEM._serialized_start=309
  _LOGITEM._serialized_end=457
  _LOGSTEP._serialized_start=459
  _LOGSTEP._serialized_end=481
  _RUNINFO._serialized_start=483
  _RUNINFO._serialized_end=508
  _UPLOADARTIFACTREQUEST._serialized_start=510
  _UPLOADARTIFACTREQUEST._serialized_end=591
  _UPLOADARTIFACTRESPONSE._serialized_start=593
  _UPLOADARTIFACTRESPONSE._serialized_end=675
  _ARTIFACTRECORD._serialized_start=678
  _ARTIFACTRECORD._serialized_end=888
  _ARTIFACTENTRY._serialized_start=891
  _ARTIFACTENTRY._serialized_end=1043
  _UPLOADFILEREQUEST._serialized_start=1046
  _UPLOADFILEREQUEST._serialized_end=1347
  _UPLOADFILERESPONSE._serialized_start=1349
  _UPLOADFILERESPONSE._serialized_end=1406
  _FILERECORD._serialized_start=1408
  _FILERECORD._serialized_end=1445
  _FILEITEM._serialized_start=1447
  _FILEITEM._serialized_end=1519
  _FILEPATH._serialized_start=1521
  _FILEPATH._serialized_end=1564
  _TOTALFILEINFO._serialized_start=1566
  _TOTALFILEINFO._serialized_end=1628
  _USEARTIFACTREQUEST._serialized_start=1631
  _USEARTIFACTREQUEST._serialized_end=1795
  _USEARTIFACTRESPONSE._serialized_start=1797
  _USEARTIFACTRESPONSE._serialized_end=1911
  _DOWNLOADFILEREQUEST._serialized_start=1914
  _DOWNLOADFILEREQUEST._serialized_end=2124
  _DOWNLOADFILERESPONSE._serialized_start=2126
  _DOWNLOADFILERESPONSE._serialized_end=2219
  _CONFIGITEM._serialized_start=2222
  _CONFIGITEM._serialized_end=2373
  _UPDATECONFIGREQUEST._serialized_start=2375
  _UPDATECONFIGREQUEST._serialized_end=2496
  _UPDATECONFIGRESPONSE._serialized_start=2498
  _UPDATECONFIGRESPONSE._serialized_end=2557
  _SENDALERTREQUEST._serialized_start=2559
  _SENDALERTREQUEST._serialized_end=2649
  _SENDALERTRESPONSE._serialized_start=2651
  _SENDALERTRESPONSE._serialized_end=2707
  _RESOURCE._serialized_start=2710
  _RESOURCE._serialized_end=3151
# @@protoc_insertion_point(module_scope)
